@@ -3,6 +3,7 @@ from typing import Any, Dict, Mapping, Optional
 import pandas as pd
 
 from omnipath.constants._constants import InteractionDataset
+from omnipath._core.requests._utils import _ERROR_EMPTY_FMT
 from omnipath._core.requests._intercell import Intercell
 from omnipath._core.requests.interactions._interactions import (
     Datasets_t,
@@ -97,10 +98,16 @@ def import_intercell_network(
     receiver_params.setdefault("scope", "generic")
 
     interactions = AllInteractions.get(include=include, **interactions_params)
+    if interactions.empty:
+        raise ValueError(_ERROR_EMPTY_FMT.format(obj="interactions"))
     interactions = _swap_undirected(interactions)
 
     transmitters = Intercell.get(**transmitter_params)
+    if transmitters.empty:
+        raise ValueError(_ERROR_EMPTY_FMT.format(obj="transmitters"))
     receivers = Intercell.get(**receiver_params)
+    if receivers.empty:
+        raise ValueError(_ERROR_EMPTY_FMT.format(obj="receivers"))
 
     # fmt: off
     intracell = ['intracellular_intercellular_related', 'intracellular']
@@ -115,6 +122,8 @@ def import_intercell_network(
     receivers[["category", "parent", "database"]] = receivers[["category", "parent", "database"]].astype(str)
 
     res = pd.merge(interactions, transmitters, left_on="source", right_on="uniprot", how="inner")
+    if res.empty:
+        raise ValueError("No values are left after merging interactions and transmitters.")
     gb = res.groupby(["category", "parent", "source", "target"], as_index=False)
     # fmt: on
 
@@ -129,6 +138,8 @@ def import_intercell_network(
         right_on="uniprot",
         suffixes=["_intercell_source", "_intercell_target"],
     )
+    if res.empty:
+        raise ValueError("No values are left after merging interactions and receivers.")
     gb = res.groupby(
         [
             "category_intercell_source",
